<?php //phpcs:ignore
/**
 * Admin template file
 *
 * @package YITH\ProductCountdown
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Implements a custom select in YWPC plugin admin tab
 *
 * @class   YWPC_Custom_Select
 * @since   1.0.0
 * @author  YITH
 * @package YITH
 */
class YWPC_Custom_Select {

	/**
	 * Outputs a custom select template in plugin options panel
	 *
	 * @param array $option Option data.
	 *
	 * @return  void
	 * @since   1.0.0
	 * @author  Alberto Ruggiero <alberto.ruggiero@yithemes.com>
	 */
	public static function output( $option ) {

		$option_value   = WC_Admin_Settings::get_option( $option['id'], $option['default'] );
		$formatted_name = '';

		if ( '' !== $option_value ) {
			$product = wc_get_product( $option_value );
			if ( $product ) {
				$formatted_name = wp_kses_post( $product->get_formatted_name() );
			}

			if ( version_compare( WC()->version, '2.7.0', '>=' ) ) {
				$formatted_name = array( $option_value => $formatted_name );
			}
		}

		$args = array(
			'class'            => esc_attr( $option['class'] ),
			'id'               => esc_attr( $option['id'] ),
			'name'             => esc_attr( $option['id'] ),
			'data-placeholder' => esc_html__( 'Search for a product&hellip;', 'yith-woocommerce-product-countdown' ),
			'data-allow_clear' => false,
			'data-selected'    => $formatted_name,
			'data-multiple'    => false,
			'data-action'      => 'woocommerce_json_search_products',
			'value'            => $option_value,
			'style'            => esc_attr( $option['css'] ),
		)

		?>
		<tr valign="top" class="titledesc">
			<th scope="row">
				<label for="<?php echo esc_attr( $option['id'] ); ?>"><?php echo esc_html( $option['title'] ); ?></label>
			</th>
			<td class="forminp forminp-<?php echo esc_attr( sanitize_title( $option['type'] ) ); ?>">
				<?php yit_add_select2_fields( $args ); ?>
			</td>
		</tr>
		<?php
	}

}
