<?php
/**
 * Frontend template file
 *
 * @package YITH\ProductCountdown
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( empty( $args['items'] ) ) {
	return;
}

$extra_class = ( $args['class'] ) ? $args['class'] . '-' : '';

foreach ( $args['items'] as $item_id => $item ) {

	if ( empty( $item['end_date'] ) || isset( $args['active_var'] ) && $args['active_var'] !== $item_id ) {
		continue;
	}

	$date = ywpc_get_countdown( $item['end_date'] );

	?>
	<div class="ywpc-countdown-loop ywpc-item-<?php echo esc_attr( $extra_class . $item_id ); ?>">
		<div class="ywpc-header">
			<?php echo wp_kses_post( apply_filters( 'ywpc_timer_title', esc_html__( 'Sale ends in', 'yith-woocommerce-product-countdown' ), $item['before'], $item_id ) ); ?>
		</div>
		<div class="ywpc-timer">
			<div class="ywpc-days">
				<div class="ywpc-amount">
					<?php $days = ( ( is_rtl() ) ? strrev( $date['dd'] ) : $date['dd'] ); ?>
					<span class="ywpc-char-0"><?php echo esc_attr( substr( $days, 0, 1 ) ); ?></span>
					<span class="ywpc-char-1"><?php echo esc_attr( substr( $days, 1, 1 ) ); ?></span>
					<span class="ywpc-char-2"><?php echo esc_attr( substr( $days, 2, 1 ) ); ?></span>
				</div>
				<div class="ywpc-label">
					<?php esc_html_e( 'Days', 'yith-woocommerce-product-countdown' ); ?>
				</div>
			</div>
			<div class="ywpc-hours">
				<div class="ywpc-amount">
					<?php $hours = ( ( is_rtl() ) ? strrev( $date['hh'] ) : $date['hh'] ); ?>
					<span class="ywpc-char-1"><?php echo esc_attr( substr( $hours, 0, 1 ) ); ?></span>
					<span class="ywpc-char-2"><?php echo esc_attr( substr( $hours, 1, 1 ) ); ?></span>
				</div>
				<div class="ywpc-label">
					<?php esc_html_e( 'Hours', 'yith-woocommerce-product-countdown' ); ?>
				</div>
			</div>
			<div class="ywpc-minutes">
				<div class="ywpc-amount">
					<?php $minutes = ( ( is_rtl() ) ? strrev( $date['mm'] ) : $date['mm'] ); ?>
					<span class="ywpc-char-1"><?php echo esc_attr( substr( $minutes, 0, 1 ) ); ?></span>
					<span class="ywpc-char-2"><?php echo esc_attr( substr( $minutes, 1, 1 ) ); ?></span>
				</div>
				<div class="ywpc-label">
					<?php esc_html_e( 'Minutes', 'yith-woocommerce-product-countdown' ); ?>
				</div>
			</div>
			<div class="ywpc-seconds">
				<div class="ywpc-amount">
					<?php $seconds = ( ( is_rtl() ) ? strrev( $date['ss'] ) : $date['ss'] ); ?>
					<span class="ywpc-char-1"><?php echo esc_attr( substr( $seconds, 0, 1 ) ); ?></span>
					<span class="ywpc-char-2"><?php echo esc_attr( substr( $seconds, 1, 1 ) ); ?></span>
				</div>
				<div class="ywpc-label">
					<?php esc_html_e( 'Seconds', 'yith-woocommerce-product-countdown' ); ?>
				</div>
			</div>
		</div>
		<input type="hidden" value="<?php echo esc_attr( gmdate( 'Y', $date['to'] ) ); ?>.<?php echo esc_attr( gmdate( 'm', $date['to'] ) - 1 ); ?>.<?php echo esc_attr( gmdate( 'd', $date['to'] ) ); ?>.<?php echo esc_attr( gmdate( 'H', $date['to'] ) ); ?>.<?php echo esc_attr( gmdate( 'i', $date['to'] ) ); ?>">
	</div>
	<?php
}





